@@ -95,7 +95,7 @@ class Card(MuviBase):
         response = {
                 'id': card_token
             }
-        return self.ok(response)
+        return self.ok(response=response)
 
     def get(self, customer_id: str, card_id: str):
         r = requests.get('{}/usersite/{}/cardtokens'.format(self.url, customer_id), headers=self.headers)
@@ -103,11 +103,10 @@ class Card(MuviBase):
 
         for card in cards:
             if card['token'] == card_id:
-                return self.ok(_format(card, customer_id), status=r.status_code)
-
+                return self.ok(response=_format(card, customer_id), status=r.status_code)
         return self.error(message='card not found')
 
     def list_all(self, customer_id: str):
         r = requests.get('{}/usersite/{}/cardtokens'.format(self.url, customer_id), headers=self.headers)
         cards = r.json()['tokens']
-        return self.ok({'results': [_format(card, customer_id) for card in cards]}, status=r.status_code)
+        return self.ok(response={'results': [_format(card, customer_id) for card in cards]}, status=r.status_code)
