@@ -109,7 +109,10 @@ def _format(response):
         'status': response['status'],
         'status_detail': response['status_detail'],
         'card': _format_card(response),
-        'payment_day': date
+        'payment_day': date,
+        'statement_descriptor': '',
+        'payment_method_id': '',
+        'installments': ''
     }
     return result
 
